@@ -18,6 +18,7 @@ import os
 import subprocess
 import sys
 
+from . import VERSION
 from .conf import PathConfig
 from .exceptions import RunCmdError
 from .exceptions import SystemTypeError
@@ -192,8 +193,11 @@ class SyncFiles(object):
             ssh_cmd = "ssh -p %d" % self._port
         else:
             ssh_cmd = "ssh"
+        directory = os.path.dirname(self._dest)
+        if not directory:
+            directory = self._dest
         option.append(
-            "'--rsync-path=mkdir -p %s && rsync'" % os.path.dirname(self._dest)
+            "'--rsync-path=mkdir -p %s && rsync'" % directory
         )
         option.append(
             '-e \'%s -i %s -o "%s" -o "%s" -o "%s"\''
@@ -321,10 +325,19 @@ def sync_files(
 def main():  # pylint: disable=R0914
     """程序主入口"""
     parser = argparse.ArgumentParser()
+    parser.add_argument(
+        "-v",
+        "--version",
+        required=False,
+        action="store_true",
+        dest="version",
+        default=False,
+        help="print version information",
+    )
     parser.add_argument(
         "-s",
         "--servers",
-        required=True,
+        required=False,
         action="store",
         dest="servers",
         nargs="+",
@@ -433,7 +446,13 @@ def main():  # pylint: disable=R0914
     )
 
     args = parser.parse_args()
+    if args.version:
+        print_ok("Version: %s" % VERSION)
+        return
     host_list, host_type, projects = args.servers, args.type, args.projects
+    if not host_list:
+        parser.print_help()
+        return
 
     user, port, identity_file = args.user, args.port, args.identity_file
 
